@@ -1,11 +1,8 @@
 use strict;
 use warnings;
-use utf8;
 
 package Test::Pod::Spelling;
-our $VERSION = '0.4';
-
-=encoding utf8
+our $VERSION = '0.2';
 
 =head1 NAME
 
@@ -14,8 +11,8 @@ Test::Pod::Spelling - A Test library to spell-check POD files
 =head1 SYNOPSIS
 
 	use Test::Pod::Spelling;
-    add_stopwords(qw( Goddard inine ));
 	all_pod_files_spelling_ok();
+	add_stopwords(qw( Goddard inine ));
 	done_testing();
 
 	use Test::Pod::Spelling (
@@ -40,14 +37,10 @@ plan to use the API to provide your own spell-checker.
 As illustrated in L</SYNOPSIS>, above, configuration options for C<Pod::Spelling> can
 be passed when the module is used.
 
-A list of words that can be allowed even if not in the dictionary (a stop list)
-can be supplied to the spell-checking module when this module is used, via
-L</add_stopwords>.
+A list of words that can be allowed even if not in the dictionary 
+can be supplied to the spell-checking module when this module is used.
 To help keep this list short, common POD that would upset the spell-checker
 is skipped - see L<Pod::Spelling/TEXT NOT SPELL-CHECKED> for details.
-No support is offered for inlining stoplists into Perl modules, which the
-author feels undermines testing. Patches to provide such an option will be
-applied, though, if required.
 
 =cut
 
@@ -119,10 +112,7 @@ sub import {
     
     my $caller = caller;
 
-    for my $func ( qw(
-		add_stopwords all_pod_files_spelling_ok pod_file_spelling_ok
-		skip_paths_matching
-	)) {
+    for my $func ( qw( add_stopwords all_pod_files_spelling_ok pod_file_spelling_ok )) {
         no strict 'refs';
         *{$caller."::".$func} = \&$func;
     }
@@ -131,30 +121,7 @@ sub import {
     $Test->plan(@args);
 }
 
-=head1 EXPORTED SUBROUTINES
-
-=head2 C<skip_paths_matching($re1 [, $reN])>
-
-Supply a list of one or more pre-compiled regular
-expressions to skip any file paths they match.
-
-=cut
-
-sub skip_paths_matching {
-	my @res = @_;
-    local $Test::Builder::Level = $Test::Builder::Level + 1;
-	my $rv = 1;
-	# Make sure they are regex
-	foreach my $i (@res){
-		if (not ref $i or ref $i ne 'Regexp'){
-			$rv = 0;
-		}
-		else {
-			$Test->{_speller}->skip_paths_matching( $i );
-		}
-	}
-	return $rv;
-}
+=head1 METHODS
 
 =head2 C<all_pod_files_spelling_ok( [@entries] )>
 
@@ -169,20 +136,12 @@ sub all_pod_files_spelling_ok {
     my @paths = map { -d $_ ? Test::Pod::all_pod_files($_) : $_ } @args;
     my @errors;
     
-    PATH:
-	foreach my $path (@paths){
-		foreach my $re ($Test->{_speller}->skip_paths_matching){
-			if ($path =~ $re){
-				$Test->skip("path $path because of skip_paths_matching $re");
-				next PATH;
-			}
-		}
-        # local $Test::Builder::Level = $Test::Builder::Level + 1;
+    foreach my $path (@paths){
     	push @errors, pod_file_spelling_ok( $path );
     }
-
+    
     return keys %{{
-    	map {$_=>1} grep {defined} @errors
+    	map {$_=>1} @errors
 	}};
 }
 
@@ -195,7 +154,8 @@ except that it checks the spelling of POD files.
 
 sub pod_file_spelling_ok {
 	my ($path, $name) = @_;
-	return () if exists $Test->{_skip_files}->{$path};
+	
+	return if exists $Test->{_skip_files}->{$path};
 	
 	# All good POD has =head1 NAME\n\n$TITLE - $DESCRIPTION
 	# so add that title to the dictionary. It may be a script name
@@ -207,10 +167,11 @@ sub pod_file_spelling_ok {
 	undef $file;	
 	
 	if ($pod_name){
-		my @words = $pod_name =~ s/:+/ /g;
-		$Test->{_speller}->add_allow_words(
-			$pod_name,
-			split(/\s+/, @words)
+		$Test->{_speller}->add_allow_words( $pod_name );
+		my $words;
+		($words = $pod_name) =~ s/:+/ /g;
+		$Test->{_speller}->add_allow_words( 
+			split/\s+/, $words
 		);
 	}
 	
@@ -225,12 +186,10 @@ sub pod_file_spelling_ok {
 	if (@errors){
 		foreach my $line ( 0 .. $#{ $Test->{_speller}->{errors} }){
 			my $misspelt = $Test->{_speller}->{errors}->[$line];
-			if ($misspelt and scalar @$misspelt){
-				$Test->diag( sprintf
-					'  Unknown word%s in %s (POD line %d): %s.',
-					(scalar @$misspelt==1? '':'s'),
-					$path, ($line+1), 
-					join ', ', map("\"$_\"", @$misspelt)
+			if (scalar @$misspelt){
+				$Test->diag( 
+					$path . ' (pod line ' . ($line+1) . '): '
+					. join ', ', map("\"$_\"", @$misspelt)
 				);
 			}
 		}
